@@ -1,6 +1,6 @@
 package Tapper::MCP::Daemon;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::MCP::Daemon::VERSION = '5.0.1';
+$Tapper::MCP::Daemon::VERSION = '5.0.2';
 use 5.010;
 
 use strict;
@@ -28,7 +28,7 @@ sub run
         my $self = shift;
 
         my ($command) = @ARGV ? @ARGV : @_;
-        return unless $command && grep /^$command$/, qw(start status restart stop);
+        return unless $command && grep /^$command$/, qw(start status stop);
         $self->$command;
         say $self->status_message;
 }
