@@ -2,7 +2,7 @@
 package Tapper::MCP::Master;
 our $AUTHORITY = 'cpan:TAPPER';
 # ABSTRACT: Wait for new testruns and start a new child when needed
-$Tapper::MCP::Master::VERSION = '5.0.1';
+$Tapper::MCP::Master::VERSION = '5.0.2';
 use 5.010;
         use Moose;
         use parent "Tapper::MCP";
@@ -114,6 +114,8 @@ sub cleanup_output_dir
                 my ($self, $job, $revive) = @_;
                 $self->log->debug('run_due_test');
 
+                return 1 if not $job->host;
+
                 my $system = $job->host->name;
                 my $id = $job->testrun->id;
 
@@ -182,28 +184,12 @@ sub cleanup_output_dir
                 sleep $timeout;
                 $self->handle_dead_children() if $self->dead_child;
 
-
-                my @jobs;
-                my $pid = open(my $fh, "-|");
-                if ($pid == 0) {
-                        my @jobs = $self->scheduler->get_next_job;
-                        print join ",", map {$_->id} @jobs;
-                        exit;
-                } else {
-                        my $ids_joined = <$fh>;
-                        {
-                                no warnings 'uninitialized'; # we may not have ids_joined when no test is due
-                                foreach my $next_id (split ',', $ids_joined) {
-                                        push @jobs, model('TestrunDB')->resultset('TestrunScheduling')->find($next_id);
-                                }
-                        }
-                }
-
+                my @jobs = $self->scheduler->get_next_job;
                 foreach my $job (@jobs) {
                         $self->run_due_tests($job);
                 }
-                $lastrun = time();
 
+                $lastrun = time();
                 return $lastrun;
         }
 
